@@ -1,7 +1,8 @@
-﻿
 
 
-__version__ = "0.2022.3.12"
+
+__author__ = "Jürgen Knauth"
+__version__ = "0.2023.1.30"
 
 
 
@@ -9,6 +10,7 @@ from .DirEntryX import DirEntryX
 from .DescendFilter import DescendFilter
 from .EmitFilter import EmitFilter
 from .StdEmitFilter import StdEmitFilter
+from .FileExtEmitFilter import FileExtEmitFilter
 
 from .DirWalker import DirWalker
 
